#
# spec file for package slade
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           slade
Version:        3.2.7
Release:        2.2
Summary:        An editor for DOOM maps and WAD/PK3 archives
License:        GPL-2.0-or-later
Group:          Amusements/Games/3D/Shoot
URL:            https://github.com/sirjuddington/SLADE
Source:         https://github.com/sirjuddington/SLADE/archive/refs/tags/%version.tar.gz
Patch1:         basepk3.diff
Patch2:         wx.diff
Patch3:         clzma.diff
Patch4:         0001-build-allow-deactivating-the-crash-handler-at-build-.patch
Patch10:        disable_sse.patch
BuildRequires:  ImageMagick
BuildRequires:  cmake >= 3.1
BuildRequires:  freeimage-devel
BuildRequires:  gcc-c++ >= 8
BuildRequires:  pkg-config
BuildRequires:  strip-nondeterminism
BuildRequires:  update-desktop-files
BuildRequires:  wxGTK3-devel
BuildRequires:  zip
BuildRequires:  pkgconfig(clzma)
BuildRequires:  pkgconfig(fluidsynth)
BuildRequires:  pkgconfig(ftgl)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glew)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libmpg123)
BuildRequires:  pkgconfig(sfml-all)
BuildRequires:  pkgconfig(x11)
%if 0%{?suse_version} >= 1600
BuildRequires:  fmt-devel
%else
Provides:       bundled(fmt) = 10
%endif
Provides:       bundled(dumb) = 0.9.3

%description
SLADE is an editor for Doom-engine based games and source
ports. It has the ability to view, modify, and write many different
game-specific formats, and even convert between some of them, or
from/to other generic formats such as PNG.

%prep
%autosetup -p1 -n SLADE-%version

%build
%define _lto_cflags %nil
export CFLAGS="%optflags -O0 -ggdb3 -fsanitize=address,undefined"
export CXXFLAGS="%optflags -O0 -ggdb3 -fsanitize=address,undefined"
%cmake -DNO_WEBVIEW=ON -DWX_GTK3=OFF -DNO_CRASHHANDLER=ON \
	-DCMAKE_C_FLAGS_RELWITHDEBINFO:STRING="$CFLAGS" \
	-DCMAKE_CXX_FLAGS_RELWITHDEBINFO:STRING="$CFLAGS" \
%if 0%{?suse_version} >= 1600
	-DUSE_SYSTEM_FMT:BOOL=ON \
%endif
	-DNO_LUA:BOOL=ON
%cmake_build

%install
strip-nondeterminism build/slade.pk3
%cmake_install

%files
%license LICENSE
%doc README.md
%_bindir/slade
%_datadir/slade3/
%_datadir/icons/hicolor/scalable/apps/net.mancubus.SLADE.svg
%_datadir/applications/net.mancubus.SLADE.desktop
%_datadir/metainfo/net.mancubus.SLADE.metainfo.xml

%changelog
* Wed Mar 26 2025 Jan Engelhardt <jengelh@inai.de>
- Switch to wxGTK3 backend
* Wed Dec 25 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.2.7
  * Added support for DECOHack
  * Added Blasphemer palette
  * Added support for versions 0x200 and 0x300 of
    Blood RFF archives
  * Map editor:
  * Added ability to filter the action specials list by name
* Wed Nov 27 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.2.6:
  * Support for vertical toolbars in the UI
  * Support creation of Quake PAK archives. Support for reading
    WebP and Ion Fury .art files.
  * Added EDGE-Classic support
  * Added support for Doom 32X map format
  * Added support for MBF21 features via new 'Boom + MBF21' port
    configuration
  * Added missing ZDoom special 107
  * mapeditor: Moving a sector now also moves things within it
  * ME: Added keybinds to rotate things in 2d mode (< and > by default)
  * ME: Added toggleable point light previews in 2D things mode
  * Added (experimental, unfinished) 3d floor preview support in
    3D mode (turned off by default)
- Drop patches fixed upstream:
  * 0001-build-add-cmake-option-to-skip-Lua-components-1175.patch
- Replace wxWidgets-3_0-devel for wxWidgets-devel BuildRequires:
  Package builds just fine with the newer 3.2 version.
- Add pkgconfig(libmpg123) BuildRequires: New dependency.
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Tue Jun 15 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Refresh patch to fix build on aarch64:
  * disable_sse.patch
* Tue Jun  1 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.1.13
  * Updated ZDoom, MAPINFO and ACS language definitions
  * Added extra UDMF flags
  * Fixed an issue with the "optional" keyword in TEXTURES
* Thu Apr 29 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 3.1.12a
  * Provide metainfo
- Install upstream provided metainfo and desktop file
  * Drop our versions
- Use cmake_install macro
* Sun Oct 11 2020 Jan Engelhardt <jengelh@inai.de>
- Disable Lua bindings as those fail to build
- Add 0001-build-add-cmake-option-to-skip-Lua-components-1175.patch
  for Factory.
* Sun Jun 28 2020 Jan Engelhardt <jengelh@inai.de>
- Add 0001-build-allow-deactivating-the-crash-handler-at-build-.patch
  Deactivate the crash handler, because it hangs. Let the kernel
  generate a standard dump instead.
* Mon Jun 22 2020 Jan Engelhardt <jengelh@inai.de>
- Add clzma.diff to use system-provided clzma library.
* Tue May 26 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.1.12
  * 'Run Archive' and 'Run Map' configurations have been
    separated, so they should now make more sense for each
    context.
  * Fixed an issue where clicking a toolbar and pressing enter
    would show/hide the 2nd group in the toolbar (this is what
    was causing some people to randomly lose the zoom slider in
    the gfx editor, for example).
  * Added SRB2 .dta as a valid wad file extension.
  * Resource Editor:
  * Fixed adjusted offsets not being saved after cropping an
    image.
  * Fixed wrong files being deleted in some situations when
    saving a directory.
  * Fixed "Open map in DB2" not working for maps in zip/directory
    archives.
  * Map Editor:
  * Added support for GZDoom slope plane UDMF properties.
  * Added basic support for ZScript inheritance for thing types.
* Wed Apr 29 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Refresh disable_sse.patch
* Sat Apr 18 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.1.11
  * Added a Lua scripting engine
  * Updated the start page with a new look and layout
  * Improved console panel
  * Improved support for high DPI displays
  * Added support for vanilla-compatible tall gfx patches
  * Added support for SiN archives
  * Translations now work on truecolour images
  * ZScript parsing
- Remove reproducible.patch (merged), wxChar.patch (no longer
  applicable), added wx.diff
* Tue Jun 26 2018 bwiedemann@suse.com
- Add reproducible.patch to not store extra timestamps in zip
  to make build reproducible
* Tue Jun 12 2018 jengelh@inai.de
- Fix build failure... slade wants zip, not p7zip.
- Wrap %%desktop_* into a 42.x/13.x guard.
* Wed Apr 18 2018 guillaume.gardet@opensuse.org
- Disable SSE with disable_sse.patch on non x86* archs
* Tue Jun 27 2017 luke.nukem.jones@gmail.com
- Fix broken appdata xml
* Sun May  7 2017 bwiedemann@suse.com
- use p7zip for deterministic archive file order
  and strip-nondeterminism to have fully reproducible builds
* Tue May  2 2017 bwiedemann@suse.com
- use convert -strip to make build more reproducible
* Fri Feb 10 2017 luke.nukem.jones@gmail.com
- Update to 3.1.1.5
- Add appdata.xml
- General
  * Added an option to always show acc compiler output, even on
    success
  * Various updates to game and language configurations
- Resource Editor
  * Added a button to clear the entry list filter
  * Fixed some issues when importing a palette from a PNG
  * Fixed some potential crashes when loading corrupted Doom gfx
    entries
  * Fixed some issues with converting to doom flat format
- Texture Editor
  * Patch and texture operations should now work on the correct
    item when the texture or patch list is sorted
  * Fixed PNG alpha channel being ignored for CopyAlpha/Overlay
    patches
- Map Editor
  * Added the option not to build nodes when saving a map (select
    "Don't build nodes" as the node builder)
  * Fixed a potential crash when building nodes
* Wed Dec 28 2016 jengelh@inai.de
- Restore basepk3.diff for proper search order
* Mon Dec 19 2016 luke.nukem.jones@gmail.com
- Update to version 3.1.1.4
- Remove patch basepk3.diff
- Add patch wxChar.diff
    + Corrects an issue with conversion from wxString to wxChar in
    column sort
* Sun Jul 17 2016 jengelh@inai.de
- Add basepk3.diff
* Tue Oct 20 2015 jengelh@inai.de
- Initial package (version 3.1.0.5) for build.opensuse.org
